==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/common/test-bindings.js <==
import json from 'format-json';
import {
    Action,
    ActionUtil,
    ElementUtil,
    Expectation,
    WaitCondition
} from 'protractor-base-dsl';

export const changeDisplayMode = (modeName) => {
    const selector = `.testBindings input[type="radio"].${modeName}`;
    const action = () => Action.click(selector);
    const condition = () => WaitCondition.displayed(`${selector}.active`);
    ActionUtil.repeatAction(action, condition);
};

export const toggleCheckbox = (selector) =>
    ElementUtil.elementFinder(selector).getAttribute('checked').then((checked) => {
        const action = () => Action.click(selector);
        const condition = () => WaitCondition.checkboxChecked(selector, !checked);
        ActionUtil.repeatAction(action, condition);
    });

export const displayModeCreation = () => changeDisplayMode('creation');

export const displayModeEdit = () => changeDisplayMode('edit');

export const displayModeDisplay = () => changeDisplayMode('display');

export const expectDefaultValueToEqual = (value) =>
    Expectation.textEquals('.testBindings .default-value input', value);

export const expectDefaultValueButtonToBeVisible = () =>
    Expectation.displayed('.testBindings .default-value .apply-value-btn');

export const expectPristineToEqual = (value) =>
    Expectation.textEquals('.testBindings .value.pristine', value);

export const expectValidToEqual = (value) =>
    Expectation.textEquals('.testBindings .value.valid', value);

export const expectModelToContain = (value) =>
    Expectation.textContains('.testBindings .value.model', value.toString());

export const expectObjectModelToEqual = (model) =>
    Expectation.textEquals('.testBindings .model.value', json.plain(model));

export const expectModelToEqual = (value) =>
    Expectation.textEquals('.testBindings .value.model', value.toString());

export const focus = () =>
    Action.click('.testBindings .focus-btn');

export const resetPristinity = () =>
    Action.click('.testBindings .reset-pristinity-btn');

export const setDefaultValue = (defaultValue) => {
    const inputSelector = '.testBindings .default-value input';
    Action.clearText(inputSelector);
    Action.typeText(inputSelector, defaultValue);
    Expectation.textEquals(inputSelector, defaultValue);
    Action.click('.testBindings .default-value .apply-value-btn');
};

export const show = () =>
    Action.click('.testBindings .api-show-btn');

export const toggleRequired = () =>
    toggleCheckbox('.testBindings input.required');

export const toggleOnlyUniqueSuggestion = () =>
    toggleCheckbox('.testBindings .only.unique.suggestion');

export const toggleDisabled = () =>
    toggleCheckbox('.testBindings input.disabled');

export const toggleShowMessages = () =>
    toggleCheckbox('.testBindings input.show-messages');

const TestBindings = {
    changeDisplayMode,
    displayModeCreation,
    displayModeDisplay,
    displayModeEdit,
    expectDefaultValueToEqual,
    expectDefaultValueButtonToBeVisible,
    expectValidToEqual,
    expectModelToContain,
    expectObjectModelToEqual,
    expectPristineToEqual,
    expectModelToEqual,
    focus,
    resetPristinity,
    setDefaultValue,
    show,
    toggleCheckbox,
    toggleOnlyUniqueSuggestion,
    toggleDisabled,
    toggleRequired,
    toggleShowMessages
};

export default TestBindings;
global.TestBindings = TestBindings;

==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/common/test-bindings.js <==
import json from 'format-json';
import {
    Action,
    ActionUtil,
    ElementUtil,
    Expectation,
    WaitCondition
} from 'protractor-base-dsl';

const sleepTime = 300;

export const changeDisplayMode = (modeName) => {
    const selector = `.testBindings input[type="radio"].${modeName}`;
    const action = () => Action.jsClick(selector);
    const condition = () => WaitCondition.displayed(`${selector}.active`);
    ActionUtil.repeatAction(action, condition);
};

export const toggleCheckbox = (selector) =>
    ElementUtil.elementFinder(selector).getAttribute('checked').then((checked) => {
        const action = () => Action.jsClick(selector);
        const condition = () => WaitCondition.checkboxChecked(selector, !checked);
        ActionUtil.repeatAction(action, condition);
    });

export const displayModeCreation = () => changeDisplayMode('creation');

export const displayModeEdit = () => changeDisplayMode('edit');

export const displayModeDisplay = () => changeDisplayMode('display');

export const expectDefaultValueToEqual = (value) =>
    Expectation.textEquals('.testBindings .default-value input', value);

export const expectDefaultValueButtonToBeVisible = () =>
    Expectation.displayed('.testBindings .default-value .apply-value-btn');

export const expectPristineToEqual = (value) =>
    Expectation.textEquals('.testBindings .value.pristine', value);

export const expectValidToEqual = (value) =>
    Expectation.textEquals('.testBindings .value.valid', value);

export const expectModelToContain = (value) =>
    Expectation.textContains('.testBindings .value.model', value.toString());

export const expectObjectModelToEqual = (model) =>
    Expectation.textEquals('.testBindings .model.value', json.plain(model));

export const expectModelToEqual = (value) =>
    Expectation.textEquals('.testBindings .value.model', value.toString());

export const focus = () =>
    Action.jsClick('.testBindings .focus-btn');

const openEnumSelection = (fieldName) => {
    const containerSelector = `.testBindings .change-${fieldName}`;
    const action = () => Action.click(`${containerSelector} .show-all`);
    const condition = () => WaitCondition.present(`${containerSelector} .resize-triggers`);
    return ActionUtil.repeatAction(action, condition);
};

const openEnumAndSelect = (optionNum, fieldName) => {
    openEnumSelection(fieldName);
    const suggestionOption = `.xl-react-autocomplete-suggestion:nth-child(${optionNum}) div`;
    Action.click(`.testBindings .change-${fieldName} .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
    return browser.driver.sleep(sleepTime);
};

export const resetPristinity = () =>
    Action.jsClick('.testBindings .reset-pristinity-btn');

export const setDefaultValue = (defaultValue) => {
    const inputSelector = '.testBindings .default-value input';
    Action.clearText(inputSelector);
    Action.typeText(inputSelector, defaultValue);
    Expectation.textEquals(inputSelector, defaultValue);
    Action.jsClick('.testBindings .default-value .apply-value-btn');
};

export const show = () =>
    Action.jsClick('.testBindings .api-show-btn');

export const toggleRequired = () =>
    toggleCheckbox('.testBindings input.required');

export const toggleOnlyUniqueSuggestion = () =>
    toggleCheckbox('.testBindings .only.unique.suggestion');

export const toggleDisabled = () =>
    toggleCheckbox('.testBindings input.xl-disabled');

export const toggleShowMessages = () =>
    toggleCheckbox('.testBindings input.show-messages');

const TestBindings = {
    changeDisplayMode,
    displayModeCreation,
    displayModeDisplay,
    displayModeEdit,
    expectDefaultValueToEqual,
    expectDefaultValueButtonToBeVisible,
    expectValidToEqual,
    expectModelToContain,
    expectObjectModelToEqual,
    expectPristineToEqual,
    expectModelToEqual,
    focus,
    openEnumAndSelect,
    openEnumSelection,
    resetPristinity,
    setDefaultValue,
    show,
    toggleCheckbox,
    toggleOnlyUniqueSuggestion,
    toggleDisabled,
    toggleRequired,
    toggleShowMessages
};

export default TestBindings;
global.TestBindings = TestBindings;
